embassy-stm32

Crates

git

Versions

stm32c551re

Flavors

IdlePolarity

Enum IdlePolarity 

pub enum IdlePolarity {
    OisActive,
    OisnActive,
}
Determines which outputs are active when PWM is in idle mode

Variants



OisActive

Normal channels are forced active and complementary channels are forced inactive



OisnActive

Normal channels are forced inactive and complementary channels are forced active